@@ -7,11 +7,12 @@ X<-fdataobj[["data"]]
 tt<-fdataobj[["argvals"]]
 rtt<-fdataobj[["rangeval"]]
 nam<-fdataobj[["names"]]
-Xcen <- sweep(X,2,apply(X,2,mean),"-")
-Xcen.fdata<-fdata(Xcen,tt,rtt,nam)
-n <- nrow(Xcen);J <- ncol(Xcen)
+mm<-fdata.cen(fdataobj)
+xmean<-mm$meanX
+Xcen.fdata <- mm$Xcen
+n <- nrow(Xcen.fdata);J <- ncol(Xcen.fdata)
 Jmin<-min(c(J,n))
-eigenres <- svd(Xcen)
+eigenres <- svd(Xcen.fdata$data)
 lambdas <- eigenres$d^2/(n-1)
 vs<-fdata(t(eigenres$v),tt,rtt,list(main="pc.svd.fdata",xlab="t",ylab="rotation"))
 scores <- matrix(0,ncol=J,nrow=n)
@@ -21,6 +22,7 @@ if (norm) {
           scores[,1:Jmin] <-inprod.fdata(Xcen.fdata,vs)
           }
 else     {scores[,1:Jmin] <-inprod.fdata(Xcen.fdata,vs)}
+#else     {scores[,1:Jmin] <-Xcen.fdata$data%*%t(eigenres$v)*diff(rtt)/J}
 colnames(scores)<-paste("PC",1:J, sep = "")
-return(list("lambdas"=lambdas,"rotation"=vs,"x"=scores,"fdataobj.cen"=Xcen.fdata))
+return(list("lambdas"=lambdas,"rotation"=vs,"x"=scores,"fdataobj.cen"=Xcen.fdata,"mean"=xmean))
 }
