@@ -2,7 +2,6 @@ predict.fregre.fd<-function(object,new.fdataobj=NULL,...){
 if (is.null(object)) stop("No fregre.fd object entered")
 if (is.null(new.fdataobj)) stop("No newx entered")
 if (!is.fdata(new.fdataobj)) new.fdataobj=fdata(new.fdataobj,object$fdataobj[["argvals"]],object$fdataobj[["rangeval"]],object$fdataobj[["names"]])
-
 gg<-1:nrow(new.fdataobj)
 nas<-apply(new.fdataobj$data,1,count.na)
 if (any(nas)) {
@@ -11,8 +10,6 @@ if (any(nas)) {
    new.fdataobj$data<-new.fdataobj$data[bb,]
    gg<-gg[bb]
    }
-
-
 newx<-new.fdataobj[["data"]]
 tt<-new.fdataobj[["argvals"]]
 rtt<-new.fdataobj[["rangeval"]]
@@ -20,19 +17,19 @@ nn <- nrow(new.fdataobj)
  if (is.null(rownames(newx)))         rownames(newx) <- 1:nn
  if (object$call[[1]]=="fregre.pc") {
  a1<-object$coefficients[1]*rep(1,len=nrow(newx))
-# b2<-newx%*%(object$beta.est[["data"]])/(ncol(newx)-1)
  object$beta.est$data<-matrix(object$beta.est$data,nrow=1)
- b1<-inprod.fdata(new.fdataobj,object$beta.est)#/(ncol(newx)-1)
+# b2<-new.fdataobj$data%*%t(object$beta.est$data)
+ b1<-inprod.fdata(fdata.cen(new.fdataobj,object$pc$mean)[[1]],object$beta.est)#/(ncol(newx)-1)
  yp<- a1+b1
  }
  else {
  if (object$call[[1]]=="fregre.basis" || object$call[[1]]=="fregre.basis.cv"){
   x=newx
   basis.x=object$basis.x.opt             #
- 	xmean=apply(x,2,mean)
-  xcen=sweep(x,2,xmean,FUN="-")
-  class(xcen)="matrix"
-	x.fd=Data2fd(argvals=tt,y=t(xcen),basisobj=basis.x)
+# 	xmean=apply(x,2,mean)
+#  xcen=sweep(x,2,xmean,FUN="-")
+  xcen<-fdata.cen(new.fdataobj,object$mean)[[1]]
+	x.fd=Data2fd(argvals=tt,y=t(xcen$data),basisobj=basis.x)
   C=t(x.fd$coefs)
   if (is.vector(object$b.est)) object$b.est<-matrix(object$b.est,ncol=1,nrow=length(object$b.est))
   yp=object$a.est* rep(1,len=nn) + C%*%object$J%*%object$b.est
@@ -89,4 +86,3 @@ yp<-drop(yp)
 names(yp)<-gg
 return(yp)
 }
-
